@@ -78,6 +78,8 @@ def create_testcase_tests(test_case_string_storage_id, atomic_test_suite_name, t
             result=decoded_test_result,
             log=atomic_test_log,
             has_known_issues=bool(test_issues),
+            build=testrun.build,
+            environment=testrun.environment,
         ))
         if decoded_test_result is True:
             local_status['tests_pass'] += 1
@@ -449,12 +451,11 @@ class Tradefed(BasePlugin):
         data = extracted_file.contents.read()
         attachment = testrun.attachments.create(
             filename = name,
-            old_data = data,
             length = extracted_file.length,
             mimetype = mimetype
         )
 
-        attachment.storage.save('attachment/%s/%s' % (attachment.id, name), ContentFile(data))
+        attachment.save_file(name, data)
 
     def postprocess_testjob(self, testjob):
         # get related testjob
